@@ -403,6 +403,8 @@ class RundeckJobs(object):
         os.environ["TF_DATA_DIR"] = config_dir_location
 
         # shutil.copytree(f"{terraform_code_dir}/", f"{config_dir_location}/")
+        if not os.path.exists("$HOME/.terraform.d/plugin-cache"):
+            os.makedirs("$HOME/.terraform.d/plugin-cache")
         self.run_command(["terraform", "init", "-input=false", "-reconfigure", "-force-copy",
                           f"-backend-config", backend_config_file_location],
                          cwd=terraform_code_dir, check=True)
